/*
 *  Copyright (c) by CryptoSoft GmbH 1996-2014
 *  All Rights Reserved
 *  Licensed Material - Property of CryptoSoft GmbH
 *  This software is made available solely pursuant to the
 *  terms of a license agreement which governs its use.
 *
 *  TESTVT.C - Cast-128 Variable Text Known Answer Test
 */

#include <stdio.h>
#include "cast128.h"	 /* Cast-128 function prototypes */

/* size of key, in bytes */
#define KEYSZ	(16)
/* size of standard block, in bytes */
#define	BLKSZ	(8)

static char *algo = "Cast-128";

CAST128_KS ks;

int main(void)
{
  unsigned char kb[KEYSZ];
  unsigned char pt[BLKSZ], ct[BLKSZ];
  unsigned int i,j;

  printf("Electronic Codebook (ECB) Mode\nVariable Text Known Answer Tests\n");
  printf("Algorithm: %s\nKeysize=%u Bits\n", algo, KEYSZ*8);

  memset(kb, 0, KEYSZ);
  printf("\nKEY=");
  for (j=0; j < KEYSZ; j++) printf("%02x", kb[j]);

  for (i = 0; i < BLKSZ * 8; i++) {
    memset(pt, 0, BLKSZ);
    pt[i/8] = 0x80 >> i%8;
    cast128_init(kb, KEYSZ, &ks);
    cast128_ecbencode(pt, ct, &ks);
    printf("\n\nI=%u\nPT=", i+1);
    for (j=0; j < BLKSZ; j++) printf("%02x", pt[j]);
    printf("\nCT=");
    for (j=0; j < BLKSZ; j++) printf("%02x", ct[j]);
  }
  printf("\n");
  return 0;
}
